Dataset transformations, traversal, and reductions.
Modules
- accurate
- Numerically accurate accumulators used by parallel reductions.
Structs
- Dataset
- Lazy event dataset combining a source, read plan, and row transformations.
- Dataset
Stats - Cached statistics for an immutable dataset view.
Enums
- Cache
Storage - Memory policy for compiled event-dependent model caches.
- Memory
Policy - Strategy used to trade retained memory for execution speed.