pub struct EventBatchBuilder { /* private fields */ }Expand description
Incremental builder for a columnar EventBatch.
Implementations
Sourceimpl EventBatchBuilder
impl EventBatchBuilder
Sourcepub fn with_capacity(schema: Arc<Schema>, capacity: usize) -> Self
pub fn with_capacity(schema: Arc<Schema>, capacity: usize) -> Self
Creates an empty builder with per-column capacity.
Sourcepub fn push<P, S>(&mut self, p4s: P, scalars: S) -> LadduDataResult<&mut Self>
pub fn push<P, S>(&mut self, p4s: P, scalars: S) -> LadduDataResult<&mut Self>
Appends an unweighted event from ordered values.
Errors
Returns LadduDataError when value counts do not match the schema or
the builder already contains weighted events.
Sourcepub fn push_weighted<P, S>(
&mut self,
p4s: P,
scalars: S,
weight: f64,
) -> LadduDataResult<&mut Self>
pub fn push_weighted<P, S>( &mut self, p4s: P, scalars: S, weight: f64, ) -> LadduDataResult<&mut Self>
Appends a weighted event from ordered values.
Errors
Returns LadduDataError when value counts do not match the schema or
the builder already contains unweighted events.
Sourcepub fn push_event(&mut self, event: OwnedEvent) -> LadduDataResult<&mut Self>
pub fn push_event(&mut self, event: OwnedEvent) -> LadduDataResult<&mut Self>
Validates and appends one owned event.
Errors
Returns LadduDataError when the event shape does not match the
schema or its weight presence differs from prior events.
Sourcepub fn extend<I>(&mut self, events: I) -> LadduDataResult<&mut Self>where
I: IntoIterator<Item = OwnedEvent>,
pub fn extend<I>(&mut self, events: I) -> LadduDataResult<&mut Self>where
I: IntoIterator<Item = OwnedEvent>,
Appends all owned events from an iterator.
Errors
Returns the first LadduDataError produced by an event whose shape or
weight presence is incompatible with the builder.
Sourcepub fn finish(self) -> LadduDataResult<EventBatch>
pub fn finish(self) -> LadduDataResult<EventBatch>
Finalizes the builder into an immutable batch.
Errors
Returns LadduDataError if the accumulated columns or weights have
inconsistent lengths.