Module io

Module io 

Streaming event-source and sink abstractions and file-format adapters.

Modules

memory
In-memory event sources and sinks.
parquet
Parquet event sources and sinks.
root
ROOT event sources.

Structs

DataFragment
Metadata describing one addressable source fragment.
FragmentRead
Planned read of one source fragment.
OutputPath
Resolves a base output path for serial or distributed writes.
ReadPlan
Options controlling event-source reads.
SourceCapabilities
Optional performance and planning capabilities of an EventSource.
WritePlan
Options controlling event-sink writes.

Enums

FragmentPartitioning
Low-level assignment of source fragments or rows.
FragmentSelection
Row selection within one source fragment.
OutputMode
Policy for resolving a concrete output path.
Partitioning
Strategy for partitioning input rows across ranks.

Traits

EventSink
Consumer of schema-compatible event batches.
EventSource
Thread-safe producer of schema-compatible event batches.
FragmentedSource
Event source composed of independently addressable fragments.

Functions

fragmented_batches
Creates a planned batch iterator for a fragmented source.
plan_fragments
Assigns source fragments or rows according to a read plan.

Type Aliases

EventBatchIter
Sendable iterator of fallible event batches.