pub struct MemorySource { /* private fields */ }Expand description
Replayable in-memory event source backed by one or more batches.
Implementations
Sourceimpl MemorySource
impl MemorySource
Sourcepub fn new(batch: EventBatch) -> Self
pub fn new(batch: EventBatch) -> Self
Creates a source containing one batch.
Sourcepub fn from_batches(batches: Vec<EventBatch>) -> LadduDataResult<Self>
pub fn from_batches(batches: Vec<EventBatch>) -> LadduDataResult<Self>
Validates and creates a source from nonempty schema-compatible batches.
Errors
Returns LadduDataError when batches is empty or contains
incompatible schemas.
Sourcepub fn from_events<I>(schema: Arc<Schema>, events: I) -> LadduDataResult<Self>where
I: IntoIterator<Item = OwnedEvent>,
pub fn from_events<I>(schema: Arc<Schema>, events: I) -> LadduDataResult<Self>where
I: IntoIterator<Item = OwnedEvent>,
Collects owned events into an in-memory source.
Errors
Returns LadduDataError when an event does not match schema or
weighted and unweighted events are mixed.
Sourcepub fn schema_arc(&self) -> &Arc<Schema> ⓘ
pub fn schema_arc(&self) -> &Arc<Schema> ⓘ
Returns the shared schema.
Sourcepub fn batches_slice(&self) -> &[EventBatch]
pub fn batches_slice(&self) -> &[EventBatch]
Returns the backing batches.
Sourcepub fn into_batches(self) -> Arc<[EventBatch]> ⓘ
pub fn into_batches(self) -> Arc<[EventBatch]> ⓘ
Consumes the source and returns its shared batches.
Sourcepub fn into_batch(self) -> LadduDataResult<EventBatch>
pub fn into_batch(self) -> LadduDataResult<EventBatch>
Consumes and concatenates all batches.
Errors
Returns LadduDataError when no batches are present or their schemas
are incompatible.