Module dataset

Module dataset 

Dataset transformations, traversal, and reductions.

Modules

accurate
Numerically accurate accumulators used by parallel reductions.

Structs

Dataset
Lazy event dataset combining a source, read plan, and row transformations.
DatasetStats
Cached statistics for an immutable dataset view.

Enums

CacheStorage
Memory policy for compiled event-dependent model caches.
MemoryPolicy
Strategy used to trade retained memory for execution speed.