Streaming event-source and sink abstractions and file-format adapters.
Modules
- memory
- In-memory event sources and sinks.
- parquet
- Parquet event sources and sinks.
- root
- ROOT event sources.
Structs
- Data
Fragment - Metadata describing one addressable source fragment.
- Fragment
Read - Planned read of one source fragment.
- Output
Path - Resolves a base output path for serial or distributed writes.
- Read
Plan - Options controlling event-source reads.
- Source
Capabilities - Optional performance and planning capabilities of an
EventSource. - Write
Plan - Options controlling event-sink writes.
Enums
- Fragment
Partitioning - Low-level assignment of source fragments or rows.
- Fragment
Selection - Row selection within one source fragment.
- Output
Mode - Policy for resolving a concrete output path.
- Partitioning
- Strategy for partitioning input rows across ranks.
Traits
- Event
Sink - Consumer of schema-compatible event batches.
- Event
Source - Thread-safe producer of schema-compatible event batches.
- Fragmented
Source - Event source composed of independently addressable fragments.
Functions
- fragmented_
batches - Creates a planned batch iterator for a fragmented source.
- plan_
fragments - Assigns source fragments or rows according to a read plan.
Type Aliases
- Event
Batch Iter - Sendable iterator of fallible event batches.