pub struct Schema { /* private fields */ }Expand description
Logical names and lookup tables for four-momentum, scalar, and weight columns.
Implementations
Sourceimpl Schema
impl Schema
Sourcepub fn new(
p4s: impl IntoIterator<Item = impl Into<Name>>,
scalars: impl IntoIterator<Item = impl Into<Name>>,
has_weight: bool,
) -> LadduDataResult<Self>
pub fn new( p4s: impl IntoIterator<Item = impl Into<Name>>, scalars: impl IntoIterator<Item = impl Into<Name>>, has_weight: bool, ) -> LadduDataResult<Self>
Validates and constructs a logical schema.
Errors
Returns LadduDataError when four-momentum or scalar column names are
duplicated.
Sourcepub fn p4_index(&self, name: &str) -> Option<usize>
pub fn p4_index(&self, name: &str) -> Option<usize>
Returns the four-momentum column index for name.
Sourcepub fn scalar_index(&self, name: &str) -> Option<usize>
pub fn scalar_index(&self, name: &str) -> Option<usize>
Returns the scalar column index for name.
Sourcepub fn has_weight(&self) -> bool
pub fn has_weight(&self) -> bool
Returns whether events carry explicit weights.
Sourcepub fn require_p4(&self, name: &str) -> LadduDataResult<usize>
pub fn require_p4(&self, name: &str) -> LadduDataResult<usize>
Requires and returns a four-momentum column index.
Errors
Returns LadduDataError::MissingColumn when name is not a
four-momentum column.
Sourcepub fn require_scalar(&self, name: &str) -> LadduDataResult<usize>
pub fn require_scalar(&self, name: &str) -> LadduDataResult<usize>
Requires and returns a scalar column index.
Errors
Returns LadduDataError::MissingColumn when name is not a scalar
column.
Sourceimpl Schema
impl Schema
Sourcepub fn infer_from_columns<'a>(
columns: impl IntoIterator<Item = ColumnInfo<'a>>,
options: &SchemaInferenceOptions,
) -> LadduDataResult<Self>
pub fn infer_from_columns<'a>( columns: impl IntoIterator<Item = ColumnInfo<'a>>, options: &SchemaInferenceOptions, ) -> LadduDataResult<Self>
Infers a logical schema from available physical columns.
Errors
Returns LadduDataError when required momentum components or weights
are missing, names are ambiguous, or inferred logical names conflict.
Sourcepub fn physical_columns(&self, column_names: &SchemaColumnNames) -> Vec<Name> ⓘ
pub fn physical_columns(&self, column_names: &SchemaColumnNames) -> Vec<Name> ⓘ
Returns all physical columns required to store this schema.
Sourcepub fn validate_required_columns<'a>(
&self,
available: impl IntoIterator<Item = ColumnInfo<'a>>,
options: &SchemaInferenceOptions,
) -> LadduDataResult<()>
pub fn validate_required_columns<'a>( &self, available: impl IntoIterator<Item = ColumnInfo<'a>>, options: &SchemaInferenceOptions, ) -> LadduDataResult<()>
Validates that all physical columns required by this schema are available.
Errors
Returns LadduDataError::MissingColumn when a required physical
column is absent or has an unsupported type.